@@ -358,6 +358,16 @@ testPos()
 		val s = Arrays.asList("mary@x.test", "jdoe@example.org", "one@y.test");
 		assertIterableEquals(s, l.flattenAddrSpecs());
 	});
+	val S8 = s8.replace(',', ';');
+	t(null, null, /*UXAddress-list-test*/ S(VO, s8), S(VO, s8), S8, (l) -> {
+		// note the callback is ignored in UXAddressPathTest but used for UX
+		assertNull(l.invalidsToString(), "invalids present");
+		val a = Arrays.asList("Mary Smith <mary@x.test>", "jdoe@example.org", "Who? <one@y.test>");
+		assertIterableEquals(a, l.flattenAddresses());
+		val s = Arrays.asList("mary@x.test", "jdoe@example.org", "one@y.test");
+		assertIterableEquals(s, l.flattenAddrSpecs());
+	});
+	// ↑ but see s17 below
 	val s9 = "<boss@nil.test>, \"Giant; \\\"Big\\\" Box\" <sysservices@example.net>";
 	val S9 = S(VO, "boss@nil.test, \"Giant; \\\"Big\\\" Box\" <sysservices@example.net>");
 	t(null, null, S9, S9, s9, (l) -> {
@@ -399,7 +409,7 @@ testPos()
 	val s12 = "Undisclosed recipients:;";
 	t(SN, SV, SN, SV, s12, (l) -> {
 		assertNull(l.invalidsToString(), "invalids present");
-		val a = Collections.singletonList("Undisclosed recipients:;");
+		val a = Collections.singletonList(s12);
 		assertIterableEquals(a, l.flattenAddresses());
 		val s = Collections.emptyList();
 		assertIterableEquals(s, l.flattenAddrSpecs());
@@ -468,6 +478,18 @@ testPos()
 		val s = Collections.emptyList();
 		assertIterableEquals(s, l.flattenAddrSpecs());
 	});
+	// see s8/S8 above
+	val s17 = s8 + ", " + s12;
+	t(null, null, SN, SV, s17, (l) -> {
+		assertNull(l.invalidsToString(), "invalids present");
+		val a = Arrays.asList("Mary Smith <mary@x.test>", "jdoe@example.org", "Who? <one@y.test>", s12);
+		assertIterableEquals(a, l.flattenAddresses());
+		val s = Arrays.asList("mary@x.test", "jdoe@example.org", "one@y.test");
+		assertIterableEquals(s, l.flattenAddrSpecs());
+	});
+	val S17 = s17.replace(',', ';');
+	t(null, null, SN, SN, S17, null);
+
 	// more synthetic ones
 	val lp16 = "0123456789ABCDEF";
 	val lp32 = lp16 + lp16;
